#!/usr/bin/gnuplot
# execute instruction line above only works in linux

# usage example (all on one line): gnuplot -e "graffile='graph-file.pdf'; 
#   starttime='2019-07-24T23:30'; stoptime='2019-07-26T23:30'" basic.gp

#functions

# saturation vapour pressure at temperature t
svp(t) = 610*exp(t/(t+238.3)*17.2694)

# actual vapour pressure at temperature=t and rh%=rh
vp(t,rh) = svp(t)*rh/100

# rh expected at surface with different temperature than nearby RH sensor
rhsurface(tsensor, rhsensor, tsurface) = 100.0 * mixr(tsensor,rhsensor)/mixr(tsurface,100)


w(t,rh) = log(vp(t,rh)/610.78)
dpt(t,rh) = (w(t,rh)*238.3)/(17.294-w(t,rh))
gm3(t,rh) = vp(t,rh)*2.166/(t + 273.16)

# Mixing ratio g/kg
mixr(t,rh) = (0.62 *10**(-5)*vp(t,rh))*1000 
# Expected RH with no buffer
exprh(tout,rhout,tin) = 100*vp(tout,rhout)/svp(tin)

#end of functions

set output "sorptions.pdf"

set encoding utf8
set term pdfcairo enhanced color solid font 'Helvetica,16' size 20cm,16cm 
#set lmargin at screen 0.09
set notitle
#set title "Buffered over insulation, 18 {/Symbol \260}C average, 12 hour cycle" font "Helvetica,20"
#set xdata time
#set timefmt "%Y-%m-%dT%H:%M:%S"
#set format x "%d/%H"
set xlabel "Seconds" font "Helvetica,18" 
#set xtics 3600
set xrange [200000:600000]
#set xrange [starttime:stoptime]
set yrange [60:100]
set ytics 60,10,100
set mytics 2
set ylabel "Weight (g)" font "Helvetica,18" 
set y2range [30:70]

set y2label "RH (%)" font "Helvetica,18"
set y2tics 30,5,70
#set key below left
#set key below right height 1.5
set grid x
set grid mytics
set grid y

#set label 'RH' at graph 0.02,0.80
#set label 'Temperature' at graph 0.02,0.51
#set label 'MR' at graph 0.02,0.12
set style fill transparent solid 0.5 noborder

plot "sorption_linen_canvas_tp.txt" \
using 1:2  t 'Tight weave' with lines ls 1 \
,'' using 1:3   t 'Open weave' with lines ls 4 \
,'' using 1:4 axes x1y2  t 'RH' with lines ls 10 \

